@@ -18,10 +18,15 @@ def deploy_version(version_id, model_uri):
 	return str(response) == "200"
 
 def stop_version_deployment(version_id):
-	version = get_object('version', {'id': version_id})[0]
-	endpoint_name = version['endpoint']
-	endpoint_config_name = client_sm.describe_endpoint(EndpointName=endpoint_name)['EndpointConfigName']
-	model_name = client_sm.describe_endpoint_config(EndpointConfigName=endpoint_config_name)['ProductionVariants'][0]['ModelName']
-	client_sm.delete_endpoint(EndpointName=endpoint_name)
-	client_sm.delete_model(ModelName=model_name)
-	update_object('version', {'status': 'COMPLETED', 'endpoint': None}, {'id': version_id})
+	try:
+		version = get_object('version', {'id': version_id})[0]
+		endpoint_name = version['endpoint']
+		endpoint_config_name = client_sm.describe_endpoint(EndpointName=endpoint_name)['EndpointConfigName']
+		model_name = client_sm.describe_endpoint_config(EndpointConfigName=endpoint_config_name)['ProductionVariants'][0]['ModelName']
+		client_sm.delete_endpoint(EndpointName=endpoint_name)
+		client_sm.delete_model(ModelName=model_name)
+		update_object('version', {'status': 'COMPLETED', 'endpoint': None}, {'id': version_id})
+		return True
+	except Exception as e:
+		print(f"stop_version_deployment : ERROR : {e}")
+		return False
